@@ -28,10 +28,11 @@ package Rex::Commands::MD5;
 use strict;
 use warnings;
 
-our $VERSION = '1.12.1'; # VERSION
+our $VERSION = '1.12.2'; # VERSION
 
 use Rex::Logger;
 require Rex::Commands;
+require Rex::Commands::Run;
 use Rex::Interface::Exec;
 use Rex::Interface::File;
 use Rex::Interface::Fs;
@@ -62,34 +63,14 @@ sub md5 {
   if ( $fs->is_file($file) ) {
     Rex::Logger::debug("Calculating checksum (MD5) of $file");
 
-    my $command =
-      ( $^O =~ m/^MSWin/i && Rex::is_local() )
-      ? qq(perl -MDigest::MD5 -e "open my \$fh, '<', \$ARGV[0] or die 'Cannot open ' . \$ARGV[0]; binmode \$fh; print Digest::MD5->new->addfile(\$fh)->hexdigest;" "$file")
-      : qq(perl -MDigest::MD5 -e 'open my \$fh, "<", \$ARGV[0] or die "Cannot open " . \$ARGV[0]; binmode \$fh; print Digest::MD5->new->addfile(\$fh)->hexdigest;' '$file');
+    my $md5 = _digest_md5($file) // _binary_md5($file);
 
-    my $md5 = i_run( $command, fail_ok => 1 );
-
-    unless ( $? == 0 ) {
-
-      my $exec = Rex::Interface::Exec->create;
-
-      my $os = $exec->exec("uname -s");
-      if ( $os =~ /bsd/i ) {
-        ( undef, $md5 ) = split( / = /, $exec->exec("md5 '$file'") );
-      }
-      else {
-        ($md5) = split( /\s/, $exec->exec("md5sum '$file'") );
-      }
-
-      if ( !$md5 ) {
-        my $message = "Unable to get MD5 checksum of $file: $!";
-        Rex::Logger::info($message);
-        die($message);
-      }
+    if ( !$md5 ) {
+      my $message = "Unable to get MD5 checksum of $file: $!";
+      Rex::Logger::info($message);
+      die($message);
     }
 
-    chomp $md5;
-
     Rex::Logger::debug("MD5 checksum of $file: $md5");
 
     return $md5;
@@ -101,4 +82,38 @@ sub md5 {
   }
 }
 
+sub _digest_md5 {
+  my $file = shift;
+  my $md5;
+
+  my $command =
+    ( $^O =~ m/^MSWin/i && Rex::is_local() )
+    ? qq(perl -MDigest::MD5 -e "open my \$fh, '<', \$ARGV[0] or die 'Cannot open ' . \$ARGV[0]; binmode \$fh; print Digest::MD5->new->addfile(\$fh)->hexdigest;" "$file")
+    : qq(perl -MDigest::MD5 -e 'open my \$fh, "<", \$ARGV[0] or die "Cannot open " . \$ARGV[0]; binmode \$fh; print Digest::MD5->new->addfile(\$fh)->hexdigest;' '$file');
+
+  my $result = i_run( $command, fail_ok => 1 );
+
+  if ( $? == 0 ) {
+    $md5 = $result;
+  }
+
+  return $md5;
+}
+
+sub _binary_md5 {
+  my $file = shift;
+  my $md5;
+
+  my $exec = Rex::Interface::Exec->create;
+
+  if ( Rex::Commands::Run::can_run('md5') ) {
+    ($md5) = $exec->exec("md5 '$file'") =~ qr{\s+=\s+([a-f0-9]{32})};
+  }
+  elsif ( Rex::Commands::Run::can_run('md5sum') ) {
+    ($md5) = $exec->exec("md5sum '$file'") =~ qr{^\\?([a-f0-9]{32})\s+};
+  }
+
+  return $md5;
+}
+
 1;
